Documentation
¶
Index ¶
- Constants
- func GetActionMethodName(action Action) (string, error)
- func HasInput(action Action) bool
- func HasOnlyActionOnlyFields(action Action) bool
- func IsEdgeAction(action Action) bool
- func IsEdgeGroupAction(action Action) bool
- func IsRemoveEdgeAction(action Action) bool
- func IsRequiredField(action Action, field *field.Field) bool
- type Action
- type ActionInfo
- type AddEdgeAction
- func (action *AddEdgeAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
- func (action *AddEdgeAction) AddCustomInterfaces(a2 Action)
- func (action *AddEdgeAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
- func (action *AddEdgeAction) ExposedToGraphQL() bool
- func (action *AddEdgeAction) GetActionName() string
- func (action *AddEdgeAction) GetCustomInterfaces() []*CustomInterface
- func (action *AddEdgeAction) GetEdgeGroup() *edge.AssociationEdgeGroup
- func (action *AddEdgeAction) GetEdges() []*edge.AssociationEdge
- func (action *AddEdgeAction) GetFields() []*field.Field
- func (action *AddEdgeAction) GetGQLEnums() []*enum.GQLEnum
- func (action *AddEdgeAction) GetGraphQLName() string
- func (action *AddEdgeAction) GetInputName() string
- func (action *AddEdgeAction) GetNodeInfo() nodeinfo.NodeInfo
- func (action *AddEdgeAction) GetNonEntFields() []*NonEntField
- func (action *AddEdgeAction) GetOperation() ent.ActionOperation
- func (action *AddEdgeAction) GetTSEnums() []*enum.Enum
- func (action *AddEdgeAction) IsDeletingNode() bool
- func (action *AddEdgeAction) MutatingExistingObject() bool
- type CreateAction
- func (action *CreateAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
- func (action *CreateAction) AddCustomInterfaces(a2 Action)
- func (action *CreateAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
- func (action *CreateAction) ExposedToGraphQL() bool
- func (action *CreateAction) GetActionName() string
- func (action *CreateAction) GetCustomInterfaces() []*CustomInterface
- func (action *CreateAction) GetEdgeGroup() *edge.AssociationEdgeGroup
- func (action *CreateAction) GetEdges() []*edge.AssociationEdge
- func (action *CreateAction) GetFields() []*field.Field
- func (action *CreateAction) GetGQLEnums() []*enum.GQLEnum
- func (action *CreateAction) GetGraphQLName() string
- func (action *CreateAction) GetInputName() string
- func (action *CreateAction) GetNodeInfo() nodeinfo.NodeInfo
- func (action *CreateAction) GetNonEntFields() []*NonEntField
- func (action *CreateAction) GetOperation() ent.ActionOperation
- func (action *CreateAction) GetTSEnums() []*enum.Enum
- func (action *CreateAction) IsDeletingNode() bool
- func (action *CreateAction) MutatingExistingObject() bool
- type CustomInterface
- type DeleteAction
- func (action *DeleteAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
- func (action *DeleteAction) AddCustomInterfaces(a2 Action)
- func (action *DeleteAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
- func (action *DeleteAction) ExposedToGraphQL() bool
- func (action *DeleteAction) GetActionName() string
- func (action *DeleteAction) GetCustomInterfaces() []*CustomInterface
- func (action *DeleteAction) GetEdgeGroup() *edge.AssociationEdgeGroup
- func (action *DeleteAction) GetEdges() []*edge.AssociationEdge
- func (action *DeleteAction) GetFields() []*field.Field
- func (action *DeleteAction) GetGQLEnums() []*enum.GQLEnum
- func (action *DeleteAction) GetGraphQLName() string
- func (action *DeleteAction) GetInputName() string
- func (action *DeleteAction) GetNodeInfo() nodeinfo.NodeInfo
- func (action *DeleteAction) GetNonEntFields() []*NonEntField
- func (action *DeleteAction) GetOperation() ent.ActionOperation
- func (action *DeleteAction) GetTSEnums() []*enum.Enum
- func (action *DeleteAction) IsDeletingNode() bool
- func (action *DeleteAction) MutatingExistingObject() bool
- type EdgeActionTemplateInfo
- type EdgeGroupAction
- func (action *EdgeGroupAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
- func (action *EdgeGroupAction) AddCustomInterfaces(a2 Action)
- func (action *EdgeGroupAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
- func (action *EdgeGroupAction) ExposedToGraphQL() bool
- func (action *EdgeGroupAction) GetActionName() string
- func (action *EdgeGroupAction) GetCustomInterfaces() []*CustomInterface
- func (action *EdgeGroupAction) GetEdgeGroup() *edge.AssociationEdgeGroup
- func (action *EdgeGroupAction) GetEdges() []*edge.AssociationEdge
- func (action *EdgeGroupAction) GetFields() []*field.Field
- func (action *EdgeGroupAction) GetGQLEnums() []*enum.GQLEnum
- func (action *EdgeGroupAction) GetGraphQLName() string
- func (action *EdgeGroupAction) GetInputName() string
- func (action *EdgeGroupAction) GetNodeInfo() nodeinfo.NodeInfo
- func (action *EdgeGroupAction) GetNonEntFields() []*NonEntField
- func (action *EdgeGroupAction) GetOperation() ent.ActionOperation
- func (action *EdgeGroupAction) GetTSEnums() []*enum.Enum
- func (action *EdgeGroupAction) IsDeletingNode() bool
- func (action *EdgeGroupAction) MutatingExistingObject() bool
- type EditAction
- func (action *EditAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
- func (action *EditAction) AddCustomInterfaces(a2 Action)
- func (action *EditAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
- func (action *EditAction) ExposedToGraphQL() bool
- func (action *EditAction) GetActionName() string
- func (action *EditAction) GetCustomInterfaces() []*CustomInterface
- func (action *EditAction) GetEdgeGroup() *edge.AssociationEdgeGroup
- func (action *EditAction) GetEdges() []*edge.AssociationEdge
- func (action *EditAction) GetFields() []*field.Field
- func (action *EditAction) GetGQLEnums() []*enum.GQLEnum
- func (action *EditAction) GetGraphQLName() string
- func (action *EditAction) GetInputName() string
- func (action *EditAction) GetNodeInfo() nodeinfo.NodeInfo
- func (action *EditAction) GetNonEntFields() []*NonEntField
- func (action *EditAction) GetOperation() ent.ActionOperation
- func (action *EditAction) GetTSEnums() []*enum.Enum
- func (action *EditAction) IsDeletingNode() bool
- func (action *EditAction) MutatingExistingObject() bool
- type FieldActionTemplateInfo
- type NonEntField
- type RemoveEdgeAction
- func (action *RemoveEdgeAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
- func (action *RemoveEdgeAction) AddCustomInterfaces(a2 Action)
- func (action *RemoveEdgeAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
- func (action *RemoveEdgeAction) ExposedToGraphQL() bool
- func (action *RemoveEdgeAction) GetActionName() string
- func (action *RemoveEdgeAction) GetCustomInterfaces() []*CustomInterface
- func (action *RemoveEdgeAction) GetEdgeGroup() *edge.AssociationEdgeGroup
- func (action *RemoveEdgeAction) GetEdges() []*edge.AssociationEdge
- func (action *RemoveEdgeAction) GetFields() []*field.Field
- func (action *RemoveEdgeAction) GetGQLEnums() []*enum.GQLEnum
- func (action *RemoveEdgeAction) GetGraphQLName() string
- func (action *RemoveEdgeAction) GetInputName() string
- func (action *RemoveEdgeAction) GetNodeInfo() nodeinfo.NodeInfo
- func (action *RemoveEdgeAction) GetNonEntFields() []*NonEntField
- func (action *RemoveEdgeAction) GetOperation() ent.ActionOperation
- func (action *RemoveEdgeAction) GetTSEnums() []*enum.Enum
- func (action *RemoveEdgeAction) IsDeletingNode() bool
- func (action *RemoveEdgeAction) MutatingExistingObject() bool
Constants ¶
const NO_FIELDS = "__NO_FIELDS__"
provides a way to say this action doesn't have any fields
Variables ¶
This section is empty.
Functions ¶
func GetActionMethodName ¶
func HasOnlyActionOnlyFields ¶
func IsEdgeAction ¶
func IsEdgeGroupAction ¶
func IsRemoveEdgeAction ¶
Types ¶
type Action ¶
type Action interface {
GetFields() []*field.Field
GetNonEntFields() []*NonEntField
GetEdges() []*edge.AssociationEdge
GetEdgeGroup() *edge.AssociationEdgeGroup
GetActionName() string
ExposedToGraphQL() bool
GetGraphQLName() string
GetInputName() string // only applies in TypeScript?
MutatingExistingObject() bool // whether to add User, Note etc params
GetNodeInfo() nodeinfo.NodeInfo
GetOperation() ent.ActionOperation
IsDeletingNode() bool
AddCustomField(enttype.TSGraphQLType, *field.Field)
AddCustomNonEntField(enttype.TSGraphQLType, *NonEntField)
AddCustomInterfaces(a Action)
GetCustomInterfaces() []*CustomInterface
GetTSEnums() []*enum.Enum
GetGQLEnums() []*enum.GQLEnum
}
type ActionInfo ¶
type ActionInfo struct {
Actions []Action
// contains filtered or unexported fields
}
func NewActionInfo ¶
func NewActionInfo() *ActionInfo
func ParseActions ¶
func ParseFromInput ¶
func (*ActionInfo) GetByGraphQLName ¶
func (info *ActionInfo) GetByGraphQLName(name string) Action
func (*ActionInfo) GetByName ¶
func (info *ActionInfo) GetByName(name string) Action
type AddEdgeAction ¶
type AddEdgeAction struct {
// contains filtered or unexported fields
}
func (*AddEdgeAction) AddCustomField ¶
func (action *AddEdgeAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
func (*AddEdgeAction) AddCustomInterfaces ¶
func (action *AddEdgeAction) AddCustomInterfaces(a2 Action)
Unclear what the best solution is here but the decision here is to create (duplicate) a private interface in the action that represents the input but in GraphQL we import the existing one since GraphQL names are unique across the types and we don't crazy naming conflicts in here we can (and should?) probably namespace the private generated interface name by adding a new prefix but no conflicts yet so leaving it for now This choice isn't consistent but is the easiest path so doing that
func (*AddEdgeAction) AddCustomNonEntField ¶
func (action *AddEdgeAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
func (*AddEdgeAction) ExposedToGraphQL ¶
func (action *AddEdgeAction) ExposedToGraphQL() bool
func (*AddEdgeAction) GetActionName ¶
func (action *AddEdgeAction) GetActionName() string
func (*AddEdgeAction) GetCustomInterfaces ¶
func (action *AddEdgeAction) GetCustomInterfaces() []*CustomInterface
func (*AddEdgeAction) GetEdgeGroup ¶
func (action *AddEdgeAction) GetEdgeGroup() *edge.AssociationEdgeGroup
func (*AddEdgeAction) GetEdges ¶
func (action *AddEdgeAction) GetEdges() []*edge.AssociationEdge
func (*AddEdgeAction) GetGQLEnums ¶
func (*AddEdgeAction) GetGraphQLName ¶
func (action *AddEdgeAction) GetGraphQLName() string
func (*AddEdgeAction) GetInputName ¶
func (action *AddEdgeAction) GetInputName() string
func (*AddEdgeAction) GetNodeInfo ¶
func (*AddEdgeAction) GetNonEntFields ¶
func (action *AddEdgeAction) GetNonEntFields() []*NonEntField
func (*AddEdgeAction) GetOperation ¶
func (action *AddEdgeAction) GetOperation() ent.ActionOperation
func (*AddEdgeAction) GetTSEnums ¶
func (*AddEdgeAction) IsDeletingNode ¶
func (action *AddEdgeAction) IsDeletingNode() bool
func (*AddEdgeAction) MutatingExistingObject ¶
func (action *AddEdgeAction) MutatingExistingObject() bool
type CreateAction ¶
type CreateAction struct {
// contains filtered or unexported fields
}
func (*CreateAction) AddCustomField ¶
func (action *CreateAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
func (*CreateAction) AddCustomInterfaces ¶
func (action *CreateAction) AddCustomInterfaces(a2 Action)
Unclear what the best solution is here but the decision here is to create (duplicate) a private interface in the action that represents the input but in GraphQL we import the existing one since GraphQL names are unique across the types and we don't crazy naming conflicts in here we can (and should?) probably namespace the private generated interface name by adding a new prefix but no conflicts yet so leaving it for now This choice isn't consistent but is the easiest path so doing that
func (*CreateAction) AddCustomNonEntField ¶
func (action *CreateAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
func (*CreateAction) ExposedToGraphQL ¶
func (action *CreateAction) ExposedToGraphQL() bool
func (*CreateAction) GetActionName ¶
func (action *CreateAction) GetActionName() string
func (*CreateAction) GetCustomInterfaces ¶
func (action *CreateAction) GetCustomInterfaces() []*CustomInterface
func (*CreateAction) GetEdgeGroup ¶
func (action *CreateAction) GetEdgeGroup() *edge.AssociationEdgeGroup
func (*CreateAction) GetEdges ¶
func (action *CreateAction) GetEdges() []*edge.AssociationEdge
func (*CreateAction) GetGQLEnums ¶
func (*CreateAction) GetGraphQLName ¶
func (action *CreateAction) GetGraphQLName() string
func (*CreateAction) GetInputName ¶
func (action *CreateAction) GetInputName() string
func (*CreateAction) GetNodeInfo ¶
func (*CreateAction) GetNonEntFields ¶
func (action *CreateAction) GetNonEntFields() []*NonEntField
func (*CreateAction) GetOperation ¶
func (action *CreateAction) GetOperation() ent.ActionOperation
func (*CreateAction) GetTSEnums ¶
func (*CreateAction) IsDeletingNode ¶
func (action *CreateAction) IsDeletingNode() bool
func (*CreateAction) MutatingExistingObject ¶
func (action *CreateAction) MutatingExistingObject() bool
type CustomInterface ¶
type DeleteAction ¶
type DeleteAction struct {
// contains filtered or unexported fields
}
func (*DeleteAction) AddCustomField ¶
func (action *DeleteAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
func (*DeleteAction) AddCustomInterfaces ¶
func (action *DeleteAction) AddCustomInterfaces(a2 Action)
Unclear what the best solution is here but the decision here is to create (duplicate) a private interface in the action that represents the input but in GraphQL we import the existing one since GraphQL names are unique across the types and we don't crazy naming conflicts in here we can (and should?) probably namespace the private generated interface name by adding a new prefix but no conflicts yet so leaving it for now This choice isn't consistent but is the easiest path so doing that
func (*DeleteAction) AddCustomNonEntField ¶
func (action *DeleteAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
func (*DeleteAction) ExposedToGraphQL ¶
func (action *DeleteAction) ExposedToGraphQL() bool
func (*DeleteAction) GetActionName ¶
func (action *DeleteAction) GetActionName() string
func (*DeleteAction) GetCustomInterfaces ¶
func (action *DeleteAction) GetCustomInterfaces() []*CustomInterface
func (*DeleteAction) GetEdgeGroup ¶
func (action *DeleteAction) GetEdgeGroup() *edge.AssociationEdgeGroup
func (*DeleteAction) GetEdges ¶
func (action *DeleteAction) GetEdges() []*edge.AssociationEdge
func (*DeleteAction) GetGQLEnums ¶
func (*DeleteAction) GetGraphQLName ¶
func (action *DeleteAction) GetGraphQLName() string
func (*DeleteAction) GetInputName ¶
func (action *DeleteAction) GetInputName() string
func (*DeleteAction) GetNodeInfo ¶
func (*DeleteAction) GetNonEntFields ¶
func (action *DeleteAction) GetNonEntFields() []*NonEntField
func (*DeleteAction) GetOperation ¶
func (action *DeleteAction) GetOperation() ent.ActionOperation
func (*DeleteAction) GetTSEnums ¶
func (*DeleteAction) IsDeletingNode ¶
func (action *DeleteAction) IsDeletingNode() bool
func (*DeleteAction) MutatingExistingObject ¶
func (action *DeleteAction) MutatingExistingObject() bool
type EdgeActionTemplateInfo ¶
type EdgeActionTemplateInfo struct {
AddEntMethodName string
AddSingleIDMethodName string
AddMultiIDMethodName string
RemoveEntMethodName string
RemoveSingleIDMethodName string
RemoveMultiIDMethodName string
EdgeName string
InstanceName string
InstanceType string
// AssocEdge *edge.AssociationEdge
EdgeConst string
NodeType string
Node string
GraphQLNodeID string
TSEdgeConst string
TSGraphQLNodeID string
TSAddMethodName string
TSAddIDMethodName string
TSRemoveMethodName string
Edge edge.Edge
}
func GetEdges ¶
func GetEdges(action Action) []EdgeActionTemplateInfo
func GetEdgesFromEdges ¶
func GetEdgesFromEdges(edges []*edge.AssociationEdge) []EdgeActionTemplateInfo
ALso TODO...
type EdgeGroupAction ¶
type EdgeGroupAction struct {
// contains filtered or unexported fields
}
func (*EdgeGroupAction) AddCustomField ¶
func (action *EdgeGroupAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
func (*EdgeGroupAction) AddCustomInterfaces ¶
func (action *EdgeGroupAction) AddCustomInterfaces(a2 Action)
Unclear what the best solution is here but the decision here is to create (duplicate) a private interface in the action that represents the input but in GraphQL we import the existing one since GraphQL names are unique across the types and we don't crazy naming conflicts in here we can (and should?) probably namespace the private generated interface name by adding a new prefix but no conflicts yet so leaving it for now This choice isn't consistent but is the easiest path so doing that
func (*EdgeGroupAction) AddCustomNonEntField ¶
func (action *EdgeGroupAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
func (*EdgeGroupAction) ExposedToGraphQL ¶
func (action *EdgeGroupAction) ExposedToGraphQL() bool
func (*EdgeGroupAction) GetActionName ¶
func (action *EdgeGroupAction) GetActionName() string
func (*EdgeGroupAction) GetCustomInterfaces ¶
func (action *EdgeGroupAction) GetCustomInterfaces() []*CustomInterface
func (*EdgeGroupAction) GetEdgeGroup ¶
func (action *EdgeGroupAction) GetEdgeGroup() *edge.AssociationEdgeGroup
func (*EdgeGroupAction) GetEdges ¶
func (action *EdgeGroupAction) GetEdges() []*edge.AssociationEdge
func (*EdgeGroupAction) GetGQLEnums ¶
func (*EdgeGroupAction) GetGraphQLName ¶
func (action *EdgeGroupAction) GetGraphQLName() string
func (*EdgeGroupAction) GetInputName ¶
func (action *EdgeGroupAction) GetInputName() string
func (*EdgeGroupAction) GetNodeInfo ¶
func (*EdgeGroupAction) GetNonEntFields ¶
func (action *EdgeGroupAction) GetNonEntFields() []*NonEntField
func (*EdgeGroupAction) GetOperation ¶
func (action *EdgeGroupAction) GetOperation() ent.ActionOperation
func (*EdgeGroupAction) GetTSEnums ¶
func (*EdgeGroupAction) IsDeletingNode ¶
func (action *EdgeGroupAction) IsDeletingNode() bool
func (*EdgeGroupAction) MutatingExistingObject ¶
func (action *EdgeGroupAction) MutatingExistingObject() bool
type EditAction ¶
type EditAction struct {
// contains filtered or unexported fields
}
func (*EditAction) AddCustomField ¶
func (action *EditAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
func (*EditAction) AddCustomInterfaces ¶
func (action *EditAction) AddCustomInterfaces(a2 Action)
Unclear what the best solution is here but the decision here is to create (duplicate) a private interface in the action that represents the input but in GraphQL we import the existing one since GraphQL names are unique across the types and we don't crazy naming conflicts in here we can (and should?) probably namespace the private generated interface name by adding a new prefix but no conflicts yet so leaving it for now This choice isn't consistent but is the easiest path so doing that
func (*EditAction) AddCustomNonEntField ¶
func (action *EditAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
func (*EditAction) ExposedToGraphQL ¶
func (action *EditAction) ExposedToGraphQL() bool
func (*EditAction) GetActionName ¶
func (action *EditAction) GetActionName() string
func (*EditAction) GetCustomInterfaces ¶
func (action *EditAction) GetCustomInterfaces() []*CustomInterface
func (*EditAction) GetEdgeGroup ¶
func (action *EditAction) GetEdgeGroup() *edge.AssociationEdgeGroup
func (*EditAction) GetEdges ¶
func (action *EditAction) GetEdges() []*edge.AssociationEdge
func (*EditAction) GetGQLEnums ¶
func (*EditAction) GetGraphQLName ¶
func (action *EditAction) GetGraphQLName() string
func (*EditAction) GetInputName ¶
func (action *EditAction) GetInputName() string
func (*EditAction) GetNodeInfo ¶
func (*EditAction) GetNonEntFields ¶
func (action *EditAction) GetNonEntFields() []*NonEntField
func (*EditAction) GetOperation ¶
func (action *EditAction) GetOperation() ent.ActionOperation
func (*EditAction) GetTSEnums ¶
func (*EditAction) IsDeletingNode ¶
func (action *EditAction) IsDeletingNode() bool
func (*EditAction) MutatingExistingObject ¶
func (action *EditAction) MutatingExistingObject() bool
type FieldActionTemplateInfo ¶
type FieldActionTemplateInfo struct {
SetterMethodName string
NullableSetterMethodName string
GetterMethodName string
InstanceName string
InstanceType string
FieldKey string
FieldName string
QuotedFieldName string
QuotedDBName string
InverseEdge *edge.AssociationEdge
IsStatusEnum bool
IsGroupID bool
NodeType string
Field *field.Field
}
FieldActionTemplateInfo is passed to codegeneration template (both action and graphql) to generate the code needed for actions
func GetFields ¶
func GetFields(action Action) []FieldActionTemplateInfo
func GetFieldsFromFields ¶
func GetFieldsFromFields(fields []*field.Field) []FieldActionTemplateInfo
TODO abstract this out somewhere else...
func GetNonEntFields ¶
func GetNonEntFields(action Action) []FieldActionTemplateInfo
type NonEntField ¶
type NonEntField struct {
FieldName string
FieldType enttype.TSGraphQLType
Nullable bool // required default = true
// TODO these are both go things. ignore
// Flag enum or ID
Flag string
// this is a go-thing. ignore for TypeScript
NodeType string
}
func (*NonEntField) GetGraphQLName ¶
func (f *NonEntField) GetGraphQLName() string
func (*NonEntField) GetTsType ¶
func (f *NonEntField) GetTsType() string
don't have to deal with all the id field stuff field.Field has to deal with
func (*NonEntField) Required ¶
func (f *NonEntField) Required() bool
func (*NonEntField) TsFieldName ¶
func (f *NonEntField) TsFieldName() string
type RemoveEdgeAction ¶
type RemoveEdgeAction struct {
// contains filtered or unexported fields
}
func (*RemoveEdgeAction) AddCustomField ¶
func (action *RemoveEdgeAction) AddCustomField(typ enttype.TSGraphQLType, cf *field.Field)
func (*RemoveEdgeAction) AddCustomInterfaces ¶
func (action *RemoveEdgeAction) AddCustomInterfaces(a2 Action)
Unclear what the best solution is here but the decision here is to create (duplicate) a private interface in the action that represents the input but in GraphQL we import the existing one since GraphQL names are unique across the types and we don't crazy naming conflicts in here we can (and should?) probably namespace the private generated interface name by adding a new prefix but no conflicts yet so leaving it for now This choice isn't consistent but is the easiest path so doing that
func (*RemoveEdgeAction) AddCustomNonEntField ¶
func (action *RemoveEdgeAction) AddCustomNonEntField(typ enttype.TSGraphQLType, cf *NonEntField)
func (*RemoveEdgeAction) ExposedToGraphQL ¶
func (action *RemoveEdgeAction) ExposedToGraphQL() bool
func (*RemoveEdgeAction) GetActionName ¶
func (action *RemoveEdgeAction) GetActionName() string
func (*RemoveEdgeAction) GetCustomInterfaces ¶
func (action *RemoveEdgeAction) GetCustomInterfaces() []*CustomInterface
func (*RemoveEdgeAction) GetEdgeGroup ¶
func (action *RemoveEdgeAction) GetEdgeGroup() *edge.AssociationEdgeGroup
func (*RemoveEdgeAction) GetEdges ¶
func (action *RemoveEdgeAction) GetEdges() []*edge.AssociationEdge
func (*RemoveEdgeAction) GetGQLEnums ¶
func (*RemoveEdgeAction) GetGraphQLName ¶
func (action *RemoveEdgeAction) GetGraphQLName() string
func (*RemoveEdgeAction) GetInputName ¶
func (action *RemoveEdgeAction) GetInputName() string
func (*RemoveEdgeAction) GetNodeInfo ¶
func (*RemoveEdgeAction) GetNonEntFields ¶
func (action *RemoveEdgeAction) GetNonEntFields() []*NonEntField
func (*RemoveEdgeAction) GetOperation ¶
func (action *RemoveEdgeAction) GetOperation() ent.ActionOperation
func (*RemoveEdgeAction) GetTSEnums ¶
func (*RemoveEdgeAction) IsDeletingNode ¶
func (action *RemoveEdgeAction) IsDeletingNode() bool
func (*RemoveEdgeAction) MutatingExistingObject ¶
func (action *RemoveEdgeAction) MutatingExistingObject() bool